@@ -38,7 +38,6 @@ G_BEGIN_DECLS
 #define GLIBTOP_SUID_NETLOAD		(1 << GLIBTOP_SYSDEPS_NETLOAD)
 #define GLIBTOP_SUID_PPP		(1 << GLIBTOP_SYSDEPS_PPP)
 #define GLIBTOP_SUID_CPU		0
-#define GLIBTOP_SUID_DISK		0
 #define GLIBTOP_SUID_MEM		0
 #define GLIBTOP_SUID_UPTIME		0
 #define GLIBTOP_SUID_LOADAVG		0
@@ -48,8 +47,6 @@ G_BEGIN_DECLS
 #define GLIBTOP_SUID_NETLIST		0
 #define GLIBTOP_SUID_PROC_WD		0
 #define GLIBTOP_SUID_PROC_AFFINITY	0
-#define GLIBTOP_SUID_PROC_IO		(1 << GLIBTOP_SYSDEPS_PROC_IO)
-#define GLIBTOP_SUID_PROC_OPEN_FILES	0
 
 G_END_DECLS
 
