@@ -52,7 +52,6 @@ static const unsigned long _glibtop_sysdeps_map_entry =
 
 static const unsigned long _glibtop_sysdeps_map_entry_smaps =
 (1UL << GLIBTOP_MAP_ENTRY_SIZE) + (1UL << GLIBTOP_MAP_ENTRY_RSS) +
-(1UL << GLIBTOP_MAP_ENTRY_PSS) + (1UL << GLIBTOP_MAP_ENTRY_SWAP) +
 (1UL << GLIBTOP_MAP_ENTRY_SHARED_DIRTY) + (1UL << GLIBTOP_MAP_ENTRY_SHARED_CLEAN) +
 (1UL << GLIBTOP_MAP_ENTRY_PRIVATE_DIRTY) + (1UL << GLIBTOP_MAP_ENTRY_PRIVATE_CLEAN);
 
@@ -99,7 +98,7 @@ parse_smaps(glibtop_map_entry *entry, const char* line)
 	if ((colon = is_smap_value(line)) == NULL)
 		return FALSE;
 
-	len = colon - line;
+	len = colon - line + 1;
 	smap = _glibtop_find_smap(line, len);
 
 //		g_debug("smap %s -> %p", line, smap);
@@ -136,7 +135,7 @@ parse_line(char* line,
 {
 	/* %16llx-%16llx %4c %16llx %02hx:%02hx %llu%*[ ]%n */
 
-	char *p;
+	char *p, *next;
 
 	p = line;
 
